@@ -19,7 +19,13 @@
 
     public function view()
     {
-      $this->smarty->assign ( 'header', $this->obj_util->getHeader() );
+      $html_header = $this->obj_util->getHeader();
+      if ( !isset( $html_header[ 'css' ] ) or empty( $html_header[ 'css' ] )  )
+      {
+        $html_header[ 'css' ] = array( './css/common.css' );
+      } // end of if
+
+      $this->smarty->assign ( 'header', $html_header );
 
       $this->smarty->display( 'skeleton.tpl' );
     }
